.. _github-stats-3-9-0:

GitHub statistics for 3.9.0 (May 15, 2024)
==========================================

GitHub statistics for 2023/09/15 (tag: v3.8.0) - 2024/05/15

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 97 issues and merged 450 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/78?closed=1>`__

The following 175 authors contributed 2584 commits.

* 0taj
* Abdul Razak Taha
* Adam J. Stewart
* Adam Turner
* Aditi Gautam
* agautam478
* Alan Lau
* Albert Y. Shih
* Alec Vercruysse
* Alexander Volkov
* Alice Descoeudres
* Allan Haldane
* Amirreza Aflakparast
* Ananya Devarakonda
* ananya314
* Anja Beck
* Anjini2004
* Ant Lockyer
* Antony Lee
* Anvi Verma
* Artyom Romanov
* Augusto Borges
* avramid9
* Ben Root
* bersbersbers
* Binaya Sharma
* Cameron
* Chaoyi Hu
* chaoyihu
* Chiraag Balu
* Christoph Hasse
* ConstableCatnip
* CozyFrog
* Cyril Gadal
* Dale Dai
* Daniel Bergman
* Daniel Hitchcock
* danielcobej
* David Gilbertson
* David Stansby
* ddale1128@gmail.com
* dependabot[bot]
* Devilsaint
* dohyun
* Drew Kinneer
* DWesl
* Elisa Heckelmann
* ElisaHeck
* Elliott Sales de Andrade
* Eric Firing
* Eric Prestat
* esibinga
* Eva Sibinga
* Evgenii Radchenko
* Faisal Fawad
* Felipe Cybis Pereira
* Garrett Sward
* Gaurav-Kumar-Soni
* Gauri Chaudhari
* Gautam Sagar
* Greg Lucas
* Gurudatta Shanbhag
* hannah
* Haoying Zhang
* Hugues Hoppe
* i-jey
* iamfaham
* Ian Hunt-Isaak
* Ian Thomas
* ifEricReturnTrue
* Illviljan
* Issam
* Issam Arabi
* Jacob Stevens-Haas
* Jacob Tomlinson
* Jake
* Jake Stevens-Haas
* James Salsman
* Jaroza727
* Jeremy Farrell
* Jirka
* Jody Klymak
* Jorge Moraleda
* Joshua Stevenson
* jovianw
* João Andrade
* jpgianfaldoni
* jsdodge
* jsjeelshah
* judfs
* Juhan Oskar Hennoste
* Junpei Ota
* Katherine Turk
* katotaisei
* KheshavKumar
* Koustav Ghosh
* Kritika Verma
* Kyle Sunden
* Linyi Li
* linyilily
* lkkmpn
* Lucia Korpas
* madisonwong210
* Maggie Liu
* Marc Bresson
* Matthew Feickert
* Matthew Morrison
* Matthias Bussonnier
* Melissa Weber Mendonça
* melissawm
* mliu08
* Mostafa Noah
* MostafaNouh0011
* n-aswin
* Nabil
* nbarlowATI
* Nidaa Rabah
* Nivedita Chaudhari
* Oscar Gustafsson
* patel-zeel
* Pavel Liavonau
* Pedro
* Pedro Peçanha
* Peter Talley
* Pradeep Reddy Raamana
* Prajwal Agrawal
* Pranav Raghu
* prateetishah
* pre-commit-ci[bot]
* QuadroTec
* Rafael Tsuha
* Raghuram Sirigiri
* Raphael
* Raphael Quast
* Ratnabali Dutta
* rawwash
* rsp2210
* Ruoyi
* Ruoyi Xie
* Rushikesh Pandya
* Ruth Comer
* samGreer
* Samuel Diebolt
* saranti
* Scott Shambaugh
* Sebastian Berg
* Seohyeon Lee
* Sheepfan0828
* ShivamPathak99
* Shriya Kalakata
* shriyakalakata
* Stefan
* Steffen Rehberg
* stevezhang1999
* Sudhanshu Pandey
* Talha Irfan
* thehappycheese
* Thomas A Caswell
* Tiago Lubiana
* Tim Hoffmann
* tobias
* Tom Sarantis
* trananso
* turnipseason
* tusharkulkarni008
* UFEddy
* Vashesh08
* vicky6
* vigneshvetrivel8
* wemi3
* yangyangdotcom
* YiLun Fan
* Zach Champion
* zachjweiner
* zoehcycy

GitHub issues and pull requests:

Pull Requests (450):

* :ghpull:`28206`: Backport PR #28205 on branch v3.9.x (TST: Fix tests with older versions of ipython)
* :ghpull:`28207`: TST: Followup corrections to #28205
* :ghpull:`28205`: TST: Fix tests with older versions of ipython
* :ghpull:`28203`: Backport PR #28164 on branch v3.9.x (CI: Ensure code coverage is always uploaded)
* :ghpull:`28204`: Backport PR #28195 on branch v3.9.x (TST: Prepare for pytest 9)
* :ghpull:`28191`: DOC: Use released mpl-sphinx-theme on v3.9.x
* :ghpull:`28195`: TST: Prepare for pytest 9
* :ghpull:`28193`: Backport PR #28185 on branch v3.9.x (DOC: Bump mpl-sphinx-theme to 3.9)
* :ghpull:`28190`: Backport PR #28103 on branch v3.9.x ([DOC]: Fix compatibility with sphinx-gallery 0.16)
* :ghpull:`28164`: CI: Ensure code coverage is always uploaded
* :ghpull:`28194`: Backport PR #28188 on branch v3.9.x ([TST] Bump some tolerances for Macos ARM)
* :ghpull:`28188`: [TST] Bump some tolerances for Macos ARM
* :ghpull:`28185`: DOC: Bump mpl-sphinx-theme to 3.9
* :ghpull:`28189`: Backport PR #28181 on branch v3.9.x (DOC: Prepare release notes for 3.9)
* :ghpull:`28103`: [DOC]: Fix compatibility with sphinx-gallery 0.16
* :ghpull:`28181`: DOC: Prepare release notes for 3.9
* :ghpull:`28184`: Backport PR #28182 on branch v3.9.x (Bump custom hatch deprecation expiration)
* :ghpull:`28182`: Bump custom hatch deprecation expiration
* :ghpull:`28178`: Backport PR #28171 on branch v3.9.x (Support removing absent tools from ToolContainerBase.)
* :ghpull:`28171`: Support removing absent tools from ToolContainerBase.
* :ghpull:`28174`: Backport PR #28169 on branch v3.9.x (Clarify public-ness of some ToolContainerBase APIs.)
* :ghpull:`28169`: Clarify public-ness of some ToolContainerBase APIs.
* :ghpull:`28160`: Backport PR #28039 on branch v3.9.x (Respect vertical_axis when rotating plot interactively)
* :ghpull:`28159`: Backport PR #28157 on branch v3.9.x (Remove call to non-existent method _default_contains in Artist)
* :ghpull:`28162`: Backport PR #27948 on branch v3.9.x (Move IPython backend mapping to Matplotlib and support entry points)
* :ghpull:`28163`: Backport PR #28144 on branch v3.9.x (DOC: Refactor code in the fishbone diagram example)
* :ghpull:`28144`: DOC: Refactor code in the fishbone diagram example
* :ghpull:`27948`: Move IPython backend mapping to Matplotlib and support entry points
* :ghpull:`28039`: Respect vertical_axis when rotating plot interactively
* :ghpull:`28157`: Remove call to non-existent method _default_contains in Artist
* :ghpull:`28141`: Backport PR #27960 on branch v3.9.x (Update AppVeyor config)
* :ghpull:`28138`: Backport PR #28068 on branch v3.9.x ([TYP] Add possible type hint to ``colors`` argument in ``LinearSegmentedColormap.from_list``)
* :ghpull:`28140`: Backport PR #28136 on branch v3.9.x (Appease pycodestyle.)
* :ghpull:`27960`: Update AppVeyor config
* :ghpull:`28068`: [TYP] Add possible type hint to ``colors`` argument in ``LinearSegmentedColormap.from_list``
* :ghpull:`28136`: Appease pycodestyle.
* :ghpull:`28135`: Backport PR #28134 on branch v3.9.x (DOC: Minor improvements on quickstart)
* :ghpull:`28134`: DOC: Minor improvements on quickstart
* :ghpull:`28121`: Backport PR #28085 on branch v3.9.x (Clarify that the pgf backend is never actually used interactively.)
* :ghpull:`28120`: Backport PR #28102 on branch v3.9.x (Fix typo in color mapping documentation in quick_start.py)
* :ghpull:`28109`: Backport PR #28100 on branch v3.9.x (TST: wxcairo sometimes raises OSError on missing cairo libraries)
* :ghpull:`28100`: TST: wxcairo sometimes raises OSError on missing cairo libraries
* :ghpull:`28108`: Backport PR #28107 on branch v3.9.x ([DOC] Fix description in CapStyle example)
* :ghpull:`28107`: [DOC] Fix description in CapStyle example
* :ghpull:`28102`: Fix typo in color mapping documentation in quick_start.py
* :ghpull:`28095`: Backport PR #28094 on branch v3.9.x (DOC: exclude sphinx 7.3.*)
* :ghpull:`28081`: Backport PR #28078 on branch v3.9.x (Clarify that findfont & _find_fonts_by_props return paths.)
* :ghpull:`28080`: Backport PR #28077 on branch v3.9.x (Parent tk StringVar to the canvas widget, not to the toolbar.)
* :ghpull:`28092`: Backport PR #28032 on branch v3.9.x (FIX: ensure images are C order before passing to pillow)
* :ghpull:`28032`: FIX: ensure images are C order before passing to pillow
* :ghpull:`28088`: Backport PR #28087 on branch v3.9.x (Document Qt5 minimal version.)
* :ghpull:`28085`: Clarify that the pgf backend is never actually used interactively.
* :ghpull:`28078`: Clarify that findfont & _find_fonts_by_props return paths.
* :ghpull:`28077`: Parent tk StringVar to the canvas widget, not to the toolbar.
* :ghpull:`28062`: Backport PR #28056 on branch v3.9.x (Strip trailing spaces from log-formatter cursor output.)
* :ghpull:`28063`: Backport PR #28055 on branch v3.9.x (DOC: Improve inverted axis example)
* :ghpull:`28056`: Strip trailing spaces from log-formatter cursor output.
* :ghpull:`28049`: Backport PR #28036 on branch v3.9.x (BLD: Fetch version from setuptools_scm at build time)
* :ghpull:`28036`: BLD: Fetch version from setuptools_scm at build time
* :ghpull:`28038`: Backport PR #28023 on branch v3.9.x (ci: Update merge conflict labeler)
* :ghpull:`28023`: ci: Update merge conflict labeler
* :ghpull:`28035`: Backport PR #28026 on branch v3.9.x ([DOC] reshuffle of contributing)
* :ghpull:`28026`: [DOC] reshuffle of contributing
* :ghpull:`28024`: DOC: Rewrite "Work on an issue" section
* :ghpull:`28011`: DOC: Move bug reports and feature requests to top of contributing index
* :ghpull:`27747`: Move doc/users/installing/ to doc/install/
* :ghpull:`27952`: ENH: Align titles
* :ghpull:`28017`: Merge up v3.8.4
* :ghpull:`28014`: Improve timeline example.
* :ghpull:`28019`: DOC: correct path to mpl_toolkits reference images
* :ghpull:`26981`: Fixes Issue #26377 - Auto-escape % Symbol in Latex in pie labels
* :ghpull:`28007`: wx: Fix file extension for toolmanager-style toolbar
* :ghpull:`25556`: Display cursor coordinates for all axes twinned with the current one.
* :ghpull:`23597`: Always use PyQT/PySide6 for GitHub CI
* :ghpull:`28013`: Avoid plt.xticks/plt.yticks in gallery examples.
* :ghpull:`28006`: Fix deprecation warnings in ft2font extension
* :ghpull:`27723`: ci: Enable testing on M1 macOS
* :ghpull:`26375`: Add ``widths``, ``heights`` and ``angles`` setter to ``EllipseCollection``
* :ghpull:`27999`: Remove documentation that some backends don't support hatching.
* :ghpull:`26710`: Add support for High DPI displays to wxAgg backend
* :ghpull:`27148`: Correctly treat pan/zoom events of overlapping axes.
* :ghpull:`27981`: DOC: Fix label type specification in parameter descriptions
* :ghpull:`27979`: Clarify error message for bad-dimensionality in pcolorfast().
* :ghpull:`27962`: DOC: Document axes_grid1.Grid attributes
* :ghpull:`27968`: MNT: Remove remaining 3.7 deprecations
* :ghpull:`27965`: DOC: Rewrite the example illustrating bxp()
* :ghpull:`26453`: add documentation for reloading font cache
* :ghpull:`26131`: Tst/restore old tests
* :ghpull:`27730`: Add an rcparam for image.interpolation_stage.
* :ghpull:`27956`: Use PyOS_setsig in macos backend
* :ghpull:`27829`: Simplify color/marker disambiguation logic in _process_plot_format.
* :ghpull:`27840`: Add legend support for boxplots
* :ghpull:`27943`: Support Cn, n>9 in plot() shorthand format.
* :ghpull:`27950`: ci: Fix condition for publishing wheels
* :ghpull:`27909`: Add a note to pyplot docstrings referencing the corresponding object methods
* :ghpull:`27929`: DOC: Add summary lines to plot types
* :ghpull:`27915`: [BUG] Fix redirect-from Sphinx extension
* :ghpull:`27945`: DOC: Explain leading dot in object references
* :ghpull:`27947`: Update docs for ``FancyArrowPatch`` & ``Annotation`` to make it clear that ShrinkA/B parameters are in points and not fractional.
* :ghpull:`27944`: Bump the actions group with 2 updates
* :ghpull:`27932`: Fix pickling of make_axes_area_auto_adjustable'd axes.
* :ghpull:`26500`: closes #26477 ENH: Add interpolation_stage in qt figureoptions
* :ghpull:`27927`: Update docs
* :ghpull:`27916`: Revert renaming labels to tick_labels in boxplot_stats()
* :ghpull:`27931`: Highlight development_setup code snippets as bash, not python.
* :ghpull:`27856`: Support hatching in cairo backends.
* :ghpull:`27922`: Fix cbook style
* :ghpull:`27668`: MNT: prevent merging using labels + branch protection rules
* :ghpull:`27857`: Documentation edit for matshow function
* :ghpull:`27928`: DOC: Fix syntax for ToolBase.image docstring
* :ghpull:`27873`: Simplify the LineCollection example
* :ghpull:`27492`: Fix semantics of MEP22 image names.
* :ghpull:`27918`: Fix new flake8 errors from old merge
* :ghpull:`27874`: Modernize macosx backend a bit
* :ghpull:`25887`: Update ``_unpack_to_numpy`` function to convert JAX and PyTorch arrays to NumPy
* :ghpull:`27685`: Work around pyparsing diagnostic warnings
* :ghpull:`26594`: Added optional props argument to Lasso Widget __init__ to customize Lasso line
* :ghpull:`22761`: Add minor ticks on and off in Axis
* :ghpull:`22407`: Add ``set_XY`` and ``set_data`` to ``Quiver``
* :ghpull:`27901`: Rename boxplot's tick label parameter
* :ghpull:`27883`: Fix build on older macOS deployment targets
* :ghpull:`27900`: Remove empty user guide tutorials page
* :ghpull:`27885`: Clean up headers in extensions
* :ghpull:`27910`: DOC: Fix dead link in README
* :ghpull:`26567`: Use SVG inheritance diagrams now that linking has been fixed
* :ghpull:`27899`: Merge up 3.8.x into main
* :ghpull:`27905`: Improved error message for malformed colors
* :ghpull:`27906`: Override open_group, close_group methods in PathEffectRenderer
* :ghpull:`27904`: FIX: Restore D213 in flake8
* :ghpull:`27895`: Remove versions from sidebar in docs
* :ghpull:`27894`: Mark triangulation classes as final
* :ghpull:`27557`: Use :mpltype:``color`` for color types
* :ghpull:`27845`: Make sure custom alpha param does not change 'none' colors in a list of colors
* :ghpull:`27719`: Add BackendRegistry singleton class
* :ghpull:`27890`: DOC: State approximate documentation build time
* :ghpull:`27887`: BLD: Add a fallback URL for FreeType
* :ghpull:`25224`: Allow passing a transformation to secondary_xaxis/_yaxis
* :ghpull:`27886`: Fix devdocs version switcher
* :ghpull:`27884`: FIX: don't copy twice on RGB input
* :ghpull:`27087`: Convert path extension to pybind11
* :ghpull:`27867`: DOC: Update some animation related topics
* :ghpull:`27848`: FIX: handle nans in RGBA input with ScalarMappables
* :ghpull:`27821`: BLD,Cygwin: Include Python.h first in various C++ files
* :ghpull:`27457`: TST: adding tests of current clear behavior on ticks
* :ghpull:`27872`: doc: add description of ``**kwargs`` usage to collections
* :ghpull:`27868`: Use pybind11 string formatter for exception messages
* :ghpull:`27862`: Add dtype/copy args to internal testing class
* :ghpull:`27658`: Bump pydata-sphinx-theme
* :ghpull:`27303`: FIX: also exclude np.nan in RGB(A) in color mapping
* :ghpull:`27860`: Bump the actions group with 2 updates
* :ghpull:`27869`: Correctly set temporary pdf/pgf backends
* :ghpull:`27850`: Deprecate ``plot_date``
* :ghpull:`27815`: Add side option to violinplot
* :ghpull:`27836`: DOC: use ... for continuation prompt in docstrings
* :ghpull:`27819`: MNT: remove draw method args and kwargs
* :ghpull:`27813`: DOC: Update violinplot() docs
* :ghpull:`27698`: Add linting and validation of all YAML files
* :ghpull:`27811`: Fix Annulus width check
* :ghpull:`27667`: Change return type of ``ion`` and ``ioff`` to fix unbound variable errors with Pyright
* :ghpull:`27807`: Expand CI pytest reporting config to ignore xfails
* :ghpull:`27806`: Remove self._renderer from AnnotationBbox and ConnectionPatch
* :ghpull:`27799`: Clarify that set_ticks() affects major/minor ticks independently
* :ghpull:`27787`: Improve documentation on boxplot and violinplot
* :ghpull:`27800`: Deactivate sidebar for release notes
* :ghpull:`27798`: Fix sphinx-gallery CSS
* :ghpull:`27462`: DOC: clarify the default value of *radius* in Patch.contains_point
* :ghpull:`27565`: MNT: arghandling subplotspec
* :ghpull:`27796`: Make mypy a bit stricter
* :ghpull:`27767`: Update handling of sequence labels for plot
* :ghpull:`27795`: Add EffVer badge
* :ghpull:`27780`: Partly revert #27711
* :ghpull:`27768`: MNT: deprecate draw method args and kwargs
* :ghpull:`27783`: Update README.md to fix citation link
* :ghpull:`27726`: TST: always set a (long) timeout for subprocess and always use our wrapper
* :ghpull:`27781`: Simplify example: Box plots with custom fill colors
* :ghpull:`27750`: Bump the actions group with 2 updates
* :ghpull:`27771`: Add marker-only and line+marker visuals to the plot() plot types
* :ghpull:`27764`: Increase size of legend in Legend guide example
* :ghpull:`26800`: Bump minimum NumPy version to 1.23
* :ghpull:`27752`: Update some Meson internals
* :ghpull:`27702`: GOV: adopt EffVer
* :ghpull:`26965`: Removal of deprecated API cm
* :ghpull:`27758`: [Doc] Remove special casing for removed method
* :ghpull:`25815`: [TST] Make jpl units instantiated with datetimes consistent with mpl converters
* :ghpull:`27729`: DOC: Improve colormap normalization example
* :ghpull:`27732`: TST: Remove memory leak test
* :ghpull:`27733`: ci: Simplify CodeQL setup
* :ghpull:`27692`: Add method to update position of arrow patch
* :ghpull:`27736`: Fix incorrect API reference in docs
* :ghpull:`27731`: DOC: Create explicit rename legend entry section in guide
* :ghpull:`27560`: Moved /users/project to /doc/project
* :ghpull:`27728`: Simplify Figure._suplabels.
* :ghpull:`27715`: Bump the actions group with 3 updates
* :ghpull:`27711`: Fix boxplot legend entries part 2
* :ghpull:`27696`: DOC: clean up automated tests section of workflow docs
* :ghpull:`27686`: Improve Locator docstrings
* :ghpull:`27704`: ci: Remove prerelease conditions from Azure Pipelines
* :ghpull:`27568`: Fix boxplot legend entries
* :ghpull:`27694`: MNT: fix labeller
* :ghpull:`26953`: MNT: test that table doesn't try to convert unitized data
* :ghpull:`27690`: Remove "Past versions" section from release notes
* :ghpull:`26926`: Closes #22011: Changes to SubFigures so it behaves like a regular artist
* :ghpull:`27469`: Fixed legend with legend location "best" when legend overlaps shaded area and text
* :ghpull:`27684`: Bump the actions group with 1 update
* :ghpull:`27665`: Axes.inset_axes - warning message removed
* :ghpull:`27688`: CI: skip code coverage upload on scheduled tests
* :ghpull:`27689`: ci: Don't include API/what's new notes in general doc labels
* :ghpull:`27640`: Add ``get_cursor_data`` to ``NonUniformImage``
* :ghpull:`27676`: BLD: Downgrade FreeType to 2.6.1 on Windows ARM
* :ghpull:`27619`: Use GH action to install reviewdog
* :ghpull:`27552`: TST: Use importlib for importing in pytest
* :ghpull:`27650`: DOC: Added call out to API guidelines to contribute + small API guidelines reorg
* :ghpull:`27618`: Add option of running stubtest using tox
* :ghpull:`27656`: Bump the actions group with 1 update
* :ghpull:`27415`: Use class form of data classes
* :ghpull:`27649`: Check for latex binary before building docs
* :ghpull:`27641`: MNT: fix api changes link in PR template
* :ghpull:`27644`: ci: Fix mpl_toolkits label
* :ghpull:`27230`: Query macOS for available system fonts.
* :ghpull:`27643`: ci: Update nightly upload for artifacts v4
* :ghpull:`27642`: Fix auto-labeler configuration
* :ghpull:`27639`: Doc: typo fix for #22699
* :ghpull:`26978`: [pre-commit.ci] pre-commit autoupdate
* :ghpull:`27563`: Enable PyPI publishing from GitHub Actions
* :ghpull:`22699`: Proof of concept for adding kwdoc content to properties using a decorator
* :ghpull:`27633`: Auto-label PRs based on changed files
* :ghpull:`27607`: Error on bad input to hexbin extents
* :ghpull:`27629`: Don't run CI twice on dependabot branches
* :ghpull:`27562`: Avoid an extra copy/resample if imshow input has no alpha
* :ghpull:`27628`: Bump the actions group with 2 updates
* :ghpull:`27626`: CI: Group dependabot updates
* :ghpull:`27589`: Don't clip PowerNorm inputs < vmin
* :ghpull:`27613`: Fix marker validator with cycler (allow mix of classes)
* :ghpull:`27615`: MNT: add spaces to PR template
* :ghpull:`27614`: DOC: Updated link in annotation API docs to point to annotation user guide
* :ghpull:`27605`: Ignore masked values in boxplot
* :ghpull:`26884`: Remove deprecated code from _fontconfig_patterns
* :ghpull:`27602`: Let FormatStrFormatter respect axes.unicode_minus.
* :ghpull:`27601`: Clarify dollar_ticks example and FormatStrFormatter docs.
* :ghpull:`24834`: Deprecate apply_theta_transforms=True to PolarTransform
* :ghpull:`27591`: Use macOS instead of OSX in comments/docs
* :ghpull:`27577`: MNT: add the running version to pickle warning message
* :ghpull:`25191`: Deprecate 'prune' kwarg to MaxNLocator
* :ghpull:`27566`: DOC: changed tag ``plot type`` to ``plot-type``
* :ghpull:`27105`: Use Axes instead of axes core library code
* :ghpull:`27575`: Add quotes round .[dev] in editable install command
* :ghpull:`27104`: Use Axes instead of axes in galleries
* :ghpull:`27373`: Transpose grid_finder tick representation.
* :ghpull:`27363`: ci: Improve coverage for compiled code
* :ghpull:`27200`: DOC: Add role for custom informal types like color
* :ghpull:`27548`: DOC: typo fix in contribute doc
* :ghpull:`27458`: Check if the mappable is in a different Figure than the one fig.color…
* :ghpull:`27546`: MNT: Clean up some style exceptions
* :ghpull:`27514`: Improve check for bbox
* :ghpull:`27265`: DOC: reorganizing contributing docs to clean up toc, better separate topics
* :ghpull:`27517`: Best-legend-location microoptimization
* :ghpull:`27540`: Bump github/codeql-action from 2 to 3
* :ghpull:`27520`: [Doc] Minor consistency changes and correction of Marker docs
* :ghpull:`27505`: Download Qhull source from Github, not Qhull servers, in meson build
* :ghpull:`27518`: Micro-optimizations related to list handling
* :ghpull:`27495`: Bump actions/stale from 8 to 9
* :ghpull:`27523`: Changes for stale GHA v9
* :ghpull:`27519`: [Doc] Improve/correct docs for 3D
* :ghpull:`27447`: TST: Compress some hist geometry tests
* :ghpull:`27513`: Fix docs and add tests for transform and deprecate ``BboxTransformToMaxOnly``
* :ghpull:`27511`: TST: Add tests for Affine2D
* :ghpull:`27424`: Added Axes.stairs test in test_datetime.py
* :ghpull:`27267`: Fix/restore secondary axis support for Transform-type functions
* :ghpull:`27013`: Add test_contour under test_datetime.py
* :ghpull:`27497`: Clarify that set_axisbelow doesn't move grids below images.
* :ghpull:`27498`: Remove unnecessary del local variables at end of Gcf.destroy.
* :ghpull:`27466`: Add test_eventplot to test_datetime.py
* :ghpull:`25905`: Use annotate coordinate systems to simplify label_subplots.
* :ghpull:`27471`: Doc: visualizing_tests and ``triage_tests`` tools
* :ghpull:`27474`: Added smoke test for Axes.matshow to test_datetime.py
* :ghpull:`27470`: Fix test visualization tool for non-PNG files
* :ghpull:`27426`: DOC: normalizing histograms
* :ghpull:`27452`: Cleanup unit_cube-methods
* :ghpull:`27431`: Added test for Axes.bar_label
* :ghpull:`26962`: Remove backend 3.7-deprecated API
* :ghpull:`27410`: Add test_vlines to test_datetime.py
* :ghpull:`27425`: Added test_fill_betweenx in test_datetime.py
* :ghpull:`27449`: Remove test_quiverkey from test_datetime.py
* :ghpull:`27427`: MNT/TST: remove xcorr and acorr from test_datetime
* :ghpull:`27390`: Add test_bxp in test_datetime.py
* :ghpull:`27428`: Added test for broken_barh to test_datetime.py
* :ghpull:`27222`: [TST] Added test_annotate in test_datetime.py
* :ghpull:`27135`: Added smoke test for Axes.stem
* :ghpull:`27343`: Fix draggable annotations on subfigures.
* :ghpull:`27033`: Add test_bar in test_datetime
* :ghpull:`27423`: Add test for fill_between in test_datetime.py
* :ghpull:`27409`: Fix setting ``_selection_completed`` in ``SpanSelector`` when spanselector is initialised using ``extents``
* :ghpull:`27440`: Fix get_path for 3d artists
* :ghpull:`27422`: TST: Cache available interactive backends
* :ghpull:`27401`: Add test_fill in test_datetime.py
* :ghpull:`27419`: DOC: Add AsinhScale to list of built-in scales
* :ghpull:`27417`: Switch pytest fixture from tmpdir to tmp_path
* :ghpull:`27172`: ENH: Change logging to warning when creating a legend with no labels
* :ghpull:`27405`: Check that xerr/yerr values are not None in errorbar
* :ghpull:`27392`: Remove test_spy from test_datetime.py
* :ghpull:`27331`: Added smoke test for Axes.barbs in test_datetime.py
* :ghpull:`27393`: MNT: Fix doc makefiles
* :ghpull:`27387`: Revert "MNT: add _version.py to .gitignore"
* :ghpull:`27347`: FIX: scale norm of collections when first array is set
* :ghpull:`27374`: MNT: add _version.py to .gitignore
* :ghpull:`19011`: Simplify tk tooltip setup.
* :ghpull:`27367`: Fix _find_fonts_by_props docstring
* :ghpull:`27359`: Fix build on PyPy
* :ghpull:`27362`: Implement SubFigure.remove.
* :ghpull:`27360`: Fix removal of colorbars on nested subgridspecs.
* :ghpull:`27211`: Add test_hlines to test_datetimes.py
* :ghpull:`27353`: Refactor AxisArtistHelpers
* :ghpull:`27357`: [DOC]: Update 3d axis limits what's new
* :ghpull:`26992`: Convert TkAgg utilities to pybind11
* :ghpull:`27215`: Add ``@QtCore.Slot()`` decorations to ``NavigationToolbar2QT``
* :ghpull:`26907`: Removal of deprecations for Contour
* :ghpull:`27285`: Factor out common parts of qt and macos interrupt handling.
* :ghpull:`27306`: Simplify GridSpec setup in make_axes_gridspec.
* :ghpull:`27313`: FIX: allow re-shown Qt windows to be re-destroyed
* :ghpull:`27184`: Use pybind11 for qhull wrapper
* :ghpull:`26794`: Use pybind11 in _c_internal_utils module
* :ghpull:`27300`: Remove idiosyncratic get_tick_iterator API.
* :ghpull:`27275`: MAINT: fix .yml in tag issue template
* :ghpull:`27288`: Use int.from_bytes instead of implementing the conversion ourselves.
* :ghpull:`27286`: Various cleanups
* :ghpull:`27279`: Tweak a few docstrings.
* :ghpull:`27256`: merge up v3.8.1
* :ghpull:`27254`: Remove redundant axes_grid colorbar examples.
* :ghpull:`27251`: webagg: Don't resize canvas if WebSocket isn't connected
* :ghpull:`27236`: Tagging Example - Tags for multiple figs demo
* :ghpull:`27245`: MNT: be more careful in Qt backend that there is actually a Figure
* :ghpull:`27158`: First attempt for individual hatching styles for stackplot
* :ghpull:`26851`: Establish draft Tag glossary and Tagging guidelines
* :ghpull:`27083`: DOC: Add tags infrastructure for gallery examples
* :ghpull:`27204`: BLD: Use NumPy nightly wheels for non-release builds
* :ghpull:`27208`: Add test_axvline to test_datetime.py
* :ghpull:`26989`: MNT: print fontname in missing glyph warning
* :ghpull:`27177`: Add test_axhline in test_datetime.py
* :ghpull:`27164`: docs: adding explanation for color in ``set_facecolor``
* :ghpull:`27175`: Deprecate mixing positional and keyword args for legend(handles, labels)
* :ghpull:`27199`: DOC: clean up links under table formatting docs
* :ghpull:`27185`: Added smoke tests for Axes.errorbar in test_datetime.py
* :ghpull:`27091`: Add test_step to test_datetime.py
* :ghpull:`27182`: Add example for plotting a bihistogram
* :ghpull:`27130`: added test_axvspan in test.datetime.py
* :ghpull:`27094`: MNT: move pytest.ini configs to .toml
* :ghpull:`27139`: added test_axhspan in test_datetime.py
* :ghpull:`27058`: DOC: concise dependency heading + small clarifications
* :ghpull:`27053`: Added info for getting compilation output from meson on autorebuild
* :ghpull:`26906`: Fix masking for Axes3D.plot()
* :ghpull:`27142`: Added smoke test for Axes.text in test_datetime.py
* :ghpull:`27024`: Add test_contourf in test_datetime.py
* :ghpull:`22347`: correctly treat pan/zoom events of overlapping axes
* :ghpull:`26900`: #26865 removing deprecations to axislines.py
* :ghpull:`26696`: DOC: Fix colLoc default
* :ghpull:`27064`: Close all plot windows of a blocking show() on Ctrl+C
* :ghpull:`26882`: Add scatter test for datetime units
* :ghpull:`27114`: add test_stackplot in test_datetime.py
* :ghpull:`27084`: Add test_barh to test_datetime.py
* :ghpull:`27110`: DOC: Move figure member sections one level down
* :ghpull:`27127`: BLD: use python3 for shebang consistent with pep-394
* :ghpull:`27111`: BLD: Fix setting FreeType build type in extension
* :ghpull:`26921`: MNT: clarify path.sketch rcparam format + test validate_sketch
* :ghpull:`27109`: TST: Use importlib for subprocess tests
* :ghpull:`27119`: Update clabel comment.
* :ghpull:`27117`: Remove datetime test for axes.pie
* :ghpull:`27095`: Deprecate nth_coord parameter from FixedAxisArtistHelper.new_fixed_axis.
* :ghpull:`27066`: Tweak array_view to be more like pybind11
* :ghpull:`27090`: Restore figaspect() API documentation
* :ghpull:`27074`: Issue #26990: Split the histogram image into two for each code block.
* :ghpull:`27086`: Rename py namespace to mpl in extension code
* :ghpull:`27082`: MAINT: Update environment.yml to match requirements files
* :ghpull:`27072`: Remove datetime test stubs for spectral methods/table
* :ghpull:`26830`: Update stix table with Unicode names
* :ghpull:`26969`: DOC: add units to user/explain [ci doc]
* :ghpull:`27028`: Added test_hist in test_datetime.py
* :ghpull:`26876`: issue: 26871 - Remove SimplePath class from patches.py
* :ghpull:`26875`: Fix Deprecation in patches.py
* :ghpull:`26890`: Removing deprecated api from patches
* :ghpull:`27037`: add test_plot_date in test_datetime.py
* :ghpull:`27012`: Bump required C++ standard to c++17
* :ghpull:`27021`: Add a section to Highlight past winners for JDH plotting contest in docs
* :ghpull:`27004`: Warning if handles and labels have a len mismatch
* :ghpull:`24061`: #24050 No error was thrown even number of handles mismatched labels
* :ghpull:`26754`: DOC: separate and clarify axisartist default tables
* :ghpull:`27020`: CI: Update scientific-python/upload-nightly-action to 0.2.0
* :ghpull:`26951`: Clarify that explicit ticklabels are used without further formatting.
* :ghpull:`26894`: Deprecate setting the timer interval while starting it.
* :ghpull:`13401`: New clear() method for Radio and Check buttons
* :ghpull:`23829`: Start transitioning to pyproject.toml
* :ghpull:`26621`: Port build system to Meson
* :ghpull:`26928`: [TYP] Add tool for running stubtest
* :ghpull:`26917`: Deprecate ContourLabeler.add_label_clabeltext.
* :ghpull:`26960`: Deprecate backend_ps.get_bbox_header, and split it for internal use.
* :ghpull:`26967`: Minor cleanups.
* :ghpull:`26909`: deprecated api tri
* :ghpull:`26946`: Inline Cursor._update into its sole caller.
* :ghpull:`26915`: DOC: Clarify description and add examples in colors.Normalize
* :ghpull:`26874`: Cleaned up the span_where class method from Polycollections.
* :ghpull:`26586`: Support standard formatters in axisartist.
* :ghpull:`26788`: Fix axh{line,span} on polar axes.
* :ghpull:`26935`: add tomli to rstcheck extras
* :ghpull:`26275`: Use pybind11 in image module
* :ghpull:`26887`: DOC: improve removal for julian dates [ci doc]
* :ghpull:`26929`: DOC: Fix removal doc for Animation attributes
* :ghpull:`26918`: 26865 Removed deprecations from quiver.py
* :ghpull:`26902`: Fixed deprecated APIs in lines.py
* :ghpull:`26903`: Simplify CheckButtons and RadioButtons click handler.
* :ghpull:`26899`: MNT: only account for Artists once in fig.get_tightbbox
* :ghpull:`26861`: QT/NavigationToolbar2: configure subplots dialog should be modal
* :ghpull:`26885`: Removed deprecated code from gridspec.py
* :ghpull:`26880`: Updated offsetbox.py
* :ghpull:`26910`: Removed the deprecated code from offsetbox.py
* :ghpull:`26905`: Add users/explain to default skip subdirs
* :ghpull:`26853`: Widgets: Remove deprecations and make arguments keyword only
* :ghpull:`26877`: Fixes deprecation in lines.py
* :ghpull:`26871`: Removed the deprecated code from ``axis.py``
* :ghpull:`26872`: Deprecated code removed in animation.py
* :ghpull:`26859`: Add datetime testing skeleton
* :ghpull:`26848`: ci: Don't install recommended packages on Circle
* :ghpull:`26852`: Remove Julian date support
* :ghpull:`26801`: [MNT]: Cleanup ticklabel_format (style=)
* :ghpull:`26840`: Reduce redundant information in _process_plot_var_args.
* :ghpull:`26731`: Explicitly set foreground color to black in svg icons
* :ghpull:`26826`: [MNT] Move NUM_VERTICES from mplutils.h to the only file it is used in
* :ghpull:`26742`: [TYP] Add typing for some private methods and modules
* :ghpull:`26819`: Reorder safe_first_element() and _safe_first_finite() code
* :ghpull:`26813`: Bump docker/setup-qemu-action from 2 to 3
* :ghpull:`26797`: Remove deprecated draw_gouraud_triangle
* :ghpull:`26815`: Remove plt.Axes from tests
* :ghpull:`26818`: Fix doc build (alternative)
* :ghpull:`26785`: merge up v3.8.0
* :ghpull:`25272`: Do not add padding to 3D axis limits when limits are manually set
* :ghpull:`26798`: Remove deprecated methods and attributed in Axes3D
* :ghpull:`26744`: Use cbook methods for string checking
* :ghpull:`26802`: specify input range in logs when image data must be clipped
* :ghpull:`26787`: Remove unused Axis private init helpers.
* :ghpull:`26629`: DOC: organize figure API
* :ghpull:`26690`: Make generated pgf code more robust against later changes of tex engine.
* :ghpull:`26577`: Bugfix: data sanitizing for barh
* :ghpull:`26684`: Update PR template doc links
* :ghpull:`26686`: PR template: shorten comment and pull up top
* :ghpull:`26670`: Added sanitize_sequence to kwargs in _preprocess_data
* :ghpull:`26634`: [MNT] Move SubplotParams from figure to gridspec
* :ghpull:`26609`: Cleanup AutoMinorLocator implementation.
* :ghpull:`26293`: Added get_xmargin(), get_ymargin() and get_zmargin() and tests.
* :ghpull:`26516`: Replace reference to %pylab by %matplotlib.
* :ghpull:`26483`: Improve legend(loc='best') warning and test
* :ghpull:`26482`: [DOC]: print pydata sphinx/mpl theme versions
* :ghpull:`23787`: Use pybind11 for C/C++ extensions

Issues (97):

* :ghissue:`28202`: [Bug]: Qt test_ipython fails on older ipython
* :ghissue:`28145`: [TST] Upcoming dependency test failures
* :ghissue:`28034`: [TST] Upcoming dependency test failures
* :ghissue:`28168`: [TST] Upcoming dependency test failures
* :ghissue:`28040`: [Bug]: vertical_axis not respected when rotating plots interactively
* :ghissue:`28146`: [Bug]: Useless recursive group in SVG output when using path_effects
* :ghissue:`28067`: [Bug]: ``LinearSegmentedColormap.from_list`` does not have all type hints for argument ``colors``
* :ghissue:`26778`: [MNT]: Numpy 2.0 support strategy
* :ghissue:`28020`: [Bug]: imsave fails on RGBA data when origin is set to lower
* :ghissue:`7720`: WXAgg backend not rendering nicely on retina
* :ghissue:`28069`: [Bug]: Can't save with custom toolbar
* :ghissue:`28005`: [Doc]: Improve contribute instructions
* :ghissue:`22376`: [ENH]: align_titles
* :ghissue:`5506`: Confusing status bar values in presence of multiple axes
* :ghissue:`4284`: Twin axis message coordinates
* :ghissue:`18940`: WxAgg backend draws the wrong size when wxpython app is high DPI aware on Windows
* :ghissue:`27792`: [ENH]: Legend entries for boxplot
* :ghissue:`27828`: [Bug]: ".C10" does not work as plot shorthand format spec
* :ghissue:`27911`: redirect not working for updated contribute page
* :ghissue:`21876`: [Doc]: redirect-from directive appears broken?
* :ghissue:`27941`: [Bug]: ShrinkA and ShrinkB are ignored in ax.annotate(arrowprops=...)
* :ghissue:`26477`: [ENH]: Add interpolation_stage selector for images in qt figureoptions
* :ghissue:`363`: Enable hatches for Cairo backend
* :ghissue:`27852`: [Bug]: matplotlib.pyplot.matshow "(first dimension of the array) are displayed horizontally" but are displayed vertically
* :ghissue:`27400`: [Bug]: tk backend confused by presence of file named "move" in current working directory
* :ghissue:`25882`: [Bug]: plt.hist takes significantly more time with torch and jax arrays
* :ghissue:`25204`: [Bug]: Pyparsing warnings emitted in mathtext
* :ghissue:`17707`: getpwuid(): uid not found: 99
* :ghissue:`27896`: [Doc]: Empty "User guide tutorials page" in docs
* :ghissue:`27824`: [Bug]: polygon from axvspan not correct in polar plot after set_xy
* :ghissue:`27378`: [ENH]: Suggest 'CN' if color is an integer
* :ghissue:`27843`: [Bug]: close_group is not called when using patheffects
* :ghissue:`27839`: [Bug]: PathCollection using alpha ignores 'none' facecolors
* :ghissue:`25119`: [ENH]: secondary_x/yaxis accept transform argument
* :ghissue:`27876`: [Doc]: Fix version switcher in devdocs
* :ghissue:`27301`: [Bug]: ``imshow`` allows RGB(A) images with ``np.nan`` values to pass
* :ghissue:`23839`: [MNT]: Add tests to codify ``ax.clear``
* :ghissue:`27652`: [Doc]: Low contrast on clicked links in dark mode
* :ghissue:`27865`: [Bug]: Zoom und pan not working after writing pdf pages.
* :ghissue:`25871`: [Bug]: Colorbar cannot be added to another figure
* :ghissue:`8072`: plot_date() ignores timezone in matplotlib version 2.0.0
* :ghissue:`27812`: [ENH]: Add split feature for violin plots
* :ghissue:`27659`: [MNT]: Improve return type of ``ioff`` and ``ion`` to improve Pyright analysis of bound variables
* :ghissue:`27805`: [Bug]: Saving a figure with indicate_inset_zoom to pdf and then pickling it causes TypeError
* :ghissue:`27701`: [Bug]: axis set_xscale('log') interferes with set_xticks
* :ghissue:`19807`: radius modification in contains_point function when linewidth is specified
* :ghissue:`27762`: [Bug]: Inconsistent treatment of list of labels in ``plot`` when the input is a dataframe
* :ghissue:`27745`: [MNT]: ``_ImageBase.draw`` and ``Axis.draw`` args and kwargs
* :ghissue:`27782`: [Doc]: Link to citation page in read me broken
* :ghissue:`8789`: legend handle size does not automatically scale with linewidth
* :ghissue:`27746`: [Doc]: Citation link in the readme.md points to 404
* :ghissue:`20853`: Add deprecation for colormaps
* :ghissue:`26865`: [MNT]: Remove 3.7-deprecated API
* :ghissue:`24168`: [Bug]: ``subprocess-exited-with-error`` when trying to build on M1 mac
* :ghissue:`27727`: [Doc]: Text in the colormap normalization gallery doesn't match the code
* :ghissue:`27635`: [Bug]: test_figure_leak_20490 repeatedly failing on CI
* :ghissue:`14217`: [Feature request] Add a way to update the position of the Arrow patch.
* :ghissue:`20512`: Bad boxplot legend entries
* :ghissue:`22011`: [Bug]: subfigures messes up with fig.legend zorder
* :ghissue:`27414`: [Bug]: Legend overlaps shaded area in fill_between with legend location "best"
* :ghissue:`23323`: Legend with "loc=best" does not try to avoid text
* :ghissue:`27648`: [Doc]: ``Axes.inset_axes`` is still experimental
* :ghissue:`27277`: [Doc]: Two license pages in docs
* :ghissue:`24648`: [Doc]: make html fail early if latex not present
* :ghissue:`27554`: [Bug]: Large image draw performance deterioration in recent releases
* :ghissue:`25239`: [Bug]: colors.PowerNorm results in incorrect colorbar
* :ghissue:`13533`: Boxplotting Masked Arrays
* :ghissue:`25967`: [Doc]: dollar_ticks example refers to unused formatter classes
* :ghissue:`24859`: [Doc]: Document color in a consistent way, including link
* :ghissue:`27159`: [Bug]: Meson build fails due to qhull link issue.
* :ghissue:`25691`: [Bug]: Secondary axis does not support Transform as functions
* :ghissue:`25860`: [Bug]: canvas pick events not working when Axes belongs to a subfigure
* :ghissue:`27361`: [Bug]: (Tight) layout engine breaks for 3D patches
* :ghissue:`27145`: [ENH]: Make "No artists with labels found to put in legend" a warning
* :ghissue:`27399`: [Bug]: None in y or yerr arrays leads to TypeError when using errorbar
* :ghissue:`13887`: Accessing default ``norm`` of a Collection removes its colors.
* :ghissue:`26593`: [ENH]: Support SubFigure.remove()
* :ghissue:`27329`: [Bug]: Removing a colorbar for an axes positioned in a subgridspec restores the axes' position to the wrong place.
* :ghissue:`27214`: [Bug]: ``NavigationToolbar2QT`` should use ``@Slot`` annotation
* :ghissue:`27146`: [ENH]: Multi hatching in ``ax.stackplot()``
* :ghissue:`27168`: [Doc]: Instructions for editable installation on Windows potentially missing a step
* :ghissue:`27174`: [MNT]: Build nightly wheels with NumPy nightly wheels
* :ghissue:`25043`: [ENH]: Plotting masked arrays correctly in 3D line plot
* :ghissue:`26990`: [Doc]: Histogram path example renders poorly in HTML
* :ghissue:`25738`: [MNT]: Improve readability of _mathtext_data.stix_virtual_fonts table
* :ghissue:`11129`: Highlight past winners for JDH plotting contest in docs
* :ghissue:`24050`: No error message in matplotlib.axes.Axes.legend() if there are more labels than handles
* :ghissue:`10922`: ENH: clear() method for widgets.RadioButtons
* :ghissue:`18295`: How to modify ticklabels in axisartist?
* :ghissue:`24996`: [Bug]: for non-rectilinear axes, axvline/axhline should behave as "draw a gridline at that x/y"
* :ghissue:`26841`: [Bug]: Global legend weird behaviors
* :ghissue:`25974`: [MNT]: Cleanup ticklabel_format(..., style=)
* :ghissue:`26786`: Please upload new dev wheel so we pick up 3.9.dev after 3.8 release
* :ghissue:`18052`: the limits of axes are inexact with mplot3d
* :ghissue:`25596`: [MNT]: Consistency on Interface
* :ghissue:`26557`: [ENH]: Nightly Python 3.12 builds
* :ghissue:`26281`: [ENH]: Add get_xmargin, get_ymargin, get_zmargin axes methods
